==> kenallclient-0.1.1.tar.gz: kenallclient-0.1.1/tests/test_client.py <==
import pytest


def test_it():
    pass


def test_create_request():
    from kenallclient.client import KenAllClient

    target = KenAllClient("testing-api-key")
    result = target.create_request("9999999")
    assert result.full_url == "https://api.kenall.jp/v1/postalcode/9999999"
    assert result.headers == {"Authorization": "Token testing-api-key"}


def test_fetch(mocker, dummy_json):
    import json
    import io
    from kenallclient.client import KenAllClient

    dummy_response = io.StringIO(json.dumps(dummy_json))
    dummy_response.headers = {"Content-Type": "application/json"}
    mock_urlopen = mocker.patch("kenallclient.client.urllib.request.urlopen")
    mock_urlopen.return_value = dummy_response

    request = object()
    target = KenAllClient("testing-api-key")
    result = target.fetch(request)
    mock_urlopen.assert_called_with(request)
    assert result

def test_fetch_unexpected_content_type(mocker, dummy_json):
    import json
    import io
    from kenallclient.client import KenAllClient

    dummy_response = io.StringIO(json.dumps(dummy_json))
    dummy_response.headers = {"Content-Type": "plain/text"}
    request_body = dummy_response.getvalue()
    mock_urlopen = mocker.patch("kenallclient.client.urllib.request.urlopen")
    mock_urlopen.return_value = dummy_response

    request = object()
    target = KenAllClient("testing-api-key")
    with pytest.raises(ValueError) as e:
        target.fetch(request)
    assert e.value.args == ("not json response", request_body)

==> kenallclient-0.2.tar.gz: kenallclient-0.2/tests/test_client.py <==
import pytest


def test_it():
    pass

@pytest.mark.parametrize(
    "api_url,expected",
    [
        pytest.param(None, "https://api.kenall.jp/v1/postalcode/"),
        pytest.param("https://kenall.example.com/v1/", "https://kenall.example.com/v1/"),
    ],
)
def test_api_url(api_url, expected):
    from kenallclient.client import KenAllClient
    target = KenAllClient("testing-api-key", api_url=api_url)
    assert target.api_url == expected


def test_create_request():
    from kenallclient.client import KenAllClient

    target = KenAllClient("testing-api-key")
    result = target.create_request("9999999")
    assert result.full_url == "https://api.kenall.jp/v1/postalcode/9999999"
    assert result.headers == {"Authorization": "Token testing-api-key"}


def test_fetch(mocker, dummy_json):
    import json
    import io
    from kenallclient.client import KenAllClient

    dummy_response = io.StringIO(json.dumps(dummy_json))
    dummy_response.headers = {"Content-Type": "application/json"}
    mock_urlopen = mocker.patch("kenallclient.client.urllib.request.urlopen")
    mock_urlopen.return_value = dummy_response

    request = object()
    target = KenAllClient("testing-api-key")
    result = target.fetch(request)
    mock_urlopen.assert_called_with(request)
    assert result

def test_fetch_unexpected_content_type(mocker, dummy_json):
    import json
    import io
    from kenallclient.client import KenAllClient

    dummy_response = io.StringIO(json.dumps(dummy_json))
    dummy_response.headers = {"Content-Type": "plain/text"}
    request_body = dummy_response.getvalue()
    mock_urlopen = mocker.patch("kenallclient.client.urllib.request.urlopen")
    mock_urlopen.return_value = dummy_response

    request = object()
    target = KenAllClient("testing-api-key")
    with pytest.raises(ValueError) as e:
        target.fetch(request)
    assert e.value.args == ("not json response", request_body)
